box_with_drill_hole

Function box_with_drill_hole 

pub fn box_with_drill_hole() -> Program
A 2 x 2 x 1 box with a blind hole drilled into its top: a rectangle sketched on the Z plane and extruded up (box), and a circle sketched on the box’s end cap extrude(box,end) and extruded back into it, cutting it out of the box (hole) — the drilled box is extrude(hole).